@@ -10,7 +10,6 @@
 
 namespace Practice
 {
-
 class ThemedBackgroundRenderer;
 
 class BoxesWidget : public ImageWidget
@@ -18,8 +17,8 @@ class BoxesWidget : public ImageWidget
     Q_OBJECT
 
 public:
-    explicit BoxesWidget(QWidget* parent = 0);
-    QSize minimumSizeHint() const Q_DECL_OVERRIDE;
+    explicit BoxesWidget(QWidget *parent = nullptr);
+    QSize minimumSizeHint() const override;
 
     void setRenderer(ThemedBackgroundRenderer *renderer);
     void setBoxCount(int boxCount);
@@ -28,16 +27,16 @@ public:
     void updatePixmap();
 
 protected:
-    bool event(QEvent *e) Q_DECL_OVERRIDE;
+    bool event(QEvent *e) override;
 
 private:
-    void drawElement(QPainter *p, const QString& id);
+    void drawElement(QPainter *p, const QString &id);
 
-    int m_boxCount;
-    int m_currentBox;
-    int m_lastBox;
+    int m_boxCount{1};
+    int m_currentBox{-1};
+    int m_lastBox{-1};
 
-    ThemedBackgroundRenderer *m_renderer;
+    ThemedBackgroundRenderer *m_renderer{nullptr};
 
     QPixmap m_box;
     QPixmap m_activeBox;
@@ -47,10 +46,10 @@ private:
     QPixmap m_arrowEnd;
 
     QRect m_rect;
-    bool m_fixedSize;
+    bool m_fixedSize{true};
 
-    int m_arrowHint;
-    int m_spacingHint;
+    int m_arrowHint{0};
+    int m_spacingHint{0};
 };
 
 }
